<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation>Hétfő</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Kedd</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Szerda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Csütörtök</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Péntek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Szombat</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Vasárnap</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation>É</translation>
    </message>
    <message>
        <source>M</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D</source>
        <translation>N</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation>Új esemény</translation>
    </message>
</context>
<context>
    <name>CMonthGraphiview</name>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Ön töröl egy eseményt.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Biztos benne, hogy törli ezt az eseményt?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Az esemény minden ismétlődését szeretné törölni, vagy csak a kiválasztott alkalmakat?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Összes törlése</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Csak ezen esemény törlése</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Az eseményt és minden jövőbeli ismétlődését szeretné törölni, vagy csak a kiválasztott alkalmakat?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Összes jövőbeli esemény törlése</translation>
    </message>
</context>
<context>
    <name>CMonthSchceduleNumButton</name>
    <message>
        <source>%1 more</source>
        <translation>%1 több</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation>Új esemény</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>Új esemény</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation>É</translation>
    </message>
</context>
<context>
    <name>CMySchceduleView</name>
    <message>
        <source>You are deleting an event.</source>
        <translation>Ön töröl egy eseményt.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Biztos benne, hogy törli ezt az eseményt?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Az esemény minden ismétlődését szeretné törölni, vagy csak a kiválasztott alkalmakat?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Összes törlése</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Csak ezen esemény törlése</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Az eseményt és minden jövőbeli ismétlődését szeretné törölni, vagy csak a kiválasztott alkalmakat?</translation>
    </message>
    <message>
        <source>My Event</source>
        <translation>Eseményem</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Összes jövőbeli esemény törlése</translation>
    </message>
</context>
<context>
    <name>CSchceduleDlg</name>
    <message>
        <source>New Event</source>
        <translation>Új esemény</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>Esemény szerkesztése</translation>
    </message>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>Az ismétlődő események valamennyiének &quot;egész nap&quot; állapotúnak kell lennie.</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation>Minden alkalmat módosítani szeretne?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation>Összes módosítása</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation>Módosítja az esemény ismétlődési szabályát.</translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation>Ön egy ismétlődő eseményt módosít.</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>Csak az esemény ezen előfordulását akarja megváltoztatni, vagy az összes jövőbeni eseményt?</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Összes</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation>Csak ezen esemény</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>Csak az esemény ezen előfordulását akarja megváltoztatni, vagy ezt és az összes jövőbeni eseményt?</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation>Minden jövőbeli esemény</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Soha</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation>Esemény idején</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation>15 perccel előtte</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation>30 perccel előtte</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation>1 órával előtte</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation>1 nappal előtte</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation>2 nappal előtte</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation>1 héttel előtte</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation>Esemény kezdete napján (09:00)</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Típus:</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation>Egész nap:</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation>Emlékeztessen:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Ismétlés:</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Naponta</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Hétköznapokon</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Hetente</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Havonta</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation>Évente</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation>Ismétlés vége:</translation>
    </message>
    <message>
        <source>After</source>
        <translation>Után</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Be</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation>időpont(ok)</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>Új esemény</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation>A befejezés időpontjának a kezdés időpontjánál későbbre kell esnie</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation>Kezdés</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation>Befejezés</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation>Emlékeztessen</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation>Ismétlés</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation>Ismétlés vége</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation>Befejezés:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Leírás:</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation>Kezdés:</translation>
    </message>
    <message>
        <source>Work</source>
        <translation>Munka</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Magánélet</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Egyéb</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation>É</translation>
    </message>
    <message>
        <source>M</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D</source>
        <translation>N</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Ön töröl egy eseményt.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Biztos benne, hogy törli ezt az eseményt?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Az esemény minden ismétlődését szeretné törölni, vagy csak a kiválasztott alkalmakat?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Összes törlése</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Csak ezen esemény törlése</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Az eseményt és minden jövőbeli ismétlődését szeretné törölni, vagy csak a kiválasztott alkalmakat?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Összes jövőbeli esemény törlése</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation>Nincs keresési eredmény</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation>EGÉSZ NAP</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation>Hét</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>É</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleItem</name>
    <message>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleView</name>
    <message>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
    <message>
        <source>No event</source>
        <translation>Nincs esemény</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation>É</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation>Naptár</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>A Naptár egy eszköz a dátumok megtekintésére, valamint egy intelligens napi tervező az élet minden dolgának ütemezéséhez.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation>Naptár</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>É</translation>
    </message>
    <message>
        <source>M</source>
        <translation>H</translation>
    </message>
    <message>
        <source>W</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D</source>
        <translation>N</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>Új esemény</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Ön töröl egy eseményt.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Biztos benne, hogy törli ezt az eseményt?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Az esemény minden ismétlődését szeretné törölni, vagy csak a kiválasztott alkalmakat?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Összes törlése</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Csak ezen esemény törlése</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Az eseményt és minden jövőbeli ismétlődését szeretné törölni, vagy csak a kiválasztott alkalmakat?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Összes jövőbeli esemény törlése</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>Új esemény</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation>Ma</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>Ma</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Segítség</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation>Esemény törlése</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Kivágás</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Beillesztés</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Összes kijelölése</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation>É</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation>Ma</translation>
    </message>
</context>
</TS>